@@ -10,7 +10,7 @@ use Crypt::Bcrypt qw(bcrypt bcrypt_check);
 use MIME::Base64 qw(decode_base64 encode_base64);
 use utf8;
 
-our $VERSION = '1.210';
+our $VERSION = '1.211';
 
 sub add {
     my $self = shift;
@@ -26,11 +26,12 @@ sub bcrypt_b64digest {
 
 sub clone {
     my $self = shift;
-    return undef unless my $clone = $self->new(
-        cost    => $self->cost,
-        salt    => $self->salt,
-        type    => $self->type,
-    );
+    return undef
+        unless my $clone = $self->new(
+        cost => $self->cost,
+        salt => $self->salt,
+        type => $self->type,
+        );
     $clone->add($self->{_buffer});
     return $clone;
 }
@@ -58,8 +59,8 @@ sub digest {
     $self->_check_cost;
     $self->_check_salt;
 
-    my $type = $self->{type} // '2a';
-    my $hash = bcrypt($self->{_buffer}, $type, $self->cost, $self->salt);
+    my $type     = defined($self->{type}) ? $self->{type} : '2a';
+    my $hash     = bcrypt($self->{_buffer}, $type, $self->cost, $self->salt);
     my $settings = $self->settings;
     $self->reset;
     return _de_base64(substr($hash, length($settings)));
@@ -68,7 +69,7 @@ sub digest {
 # new isn't actually implemented in the base class. eww.
 sub new {
     my $class = shift;
-    my $self = bless {_buffer => '',}, ref $class || $class;
+    my $self  = bless {_buffer => '',}, ref $class || $class;
     return $self unless @_;
     my $params = @_ > 1 ? {@_} : {%{$_[0]}};
     $self->cost($params->{cost})         if $params->{cost};
@@ -108,10 +109,10 @@ sub salt {
 sub settings {
     my $self = shift;
     unless (@_) {
-        my $cost = sprintf('%02d', $self->{cost});
+        my $cost        = sprintf('%02d', $self->{cost});
         my $salt_base64 = encode_base64($self->salt, "");
         $salt_base64 =~ tr{A-Za-z0-9+/=}{./A-Za-z0-9}d;
-        my $type = $self->{type} // '2a';
+        my $type = defined($self->{type}) ? $self->{type} : '2a';
         return "\$${type}\$${cost}\$${salt_base64}";
     }
     my $settings = shift;
@@ -154,9 +155,9 @@ sub _check_salt {
 }
 
 sub _de_base64 {
-	my ($text) = @_;
-	$text =~ tr#./A-Za-z0-9#A-Za-z0-9+/#;
-	return decode_base64($text);
+    my ($text) = @_;
+    $text =~ tr#./A-Za-z0-9#A-Za-z0-9+/#;
+    return decode_base64($text);
 }
 
 
@@ -180,9 +181,12 @@ Digest::Bcrypt - Perl interface to the bcrypt digest algorithm
     # You can forego the cost and salt in favor of settings strings:
     my $bcrypt = Digest->new('Bcrypt', settings => '$2a$20$GA.eY03tb02ea0DqbA.eG.');
 
-    # $cost is an integer between 1 and 31
+    # $cost is an integer between 5 and 31
     $bcrypt->cost(12);
 
+    # $type is a selection between 2a, 2b, 2x, and 2y
+    $bcrypt->type('2b');
+
     # $salt must be exactly 16 octets long
     $bcrypt->salt('abcdefgh♥stuff');
     # OR, for good, random salts:
@@ -204,11 +208,12 @@ Digest::Bcrypt - Perl interface to the bcrypt digest algorithm
 
     # Now, let's create a password hash and check it later:
     use Data::Entropy::Algorithms qw(rand_bits);
-    my $bcrypt = Digest->new('Bcrypt', cost=>20, salt=>rand_bits(16*8));
+    my $bcrypt = Digest->new('Bcrypt', type => '2b', cost => 20, salt => rand_bits(16*8));
     my $settings = $bcrypt->settings(); # save for later checks.
     my $pass_hash = $bcrypt->add('Some secret password')->digest;
+
     # much later, we can check a password against our hash via:
-    my $bcrypt = Digest->new('Bcrypt', settings=>$settings);
+    my $bcrypt = Digest->new('Bcrypt', settings => $settings);
     if ($bcrypt->add($value_from_user)->digest eq $known_pass_hash) {
         say "Your password matched";
     }
@@ -216,12 +221,18 @@ Digest::Bcrypt - Perl interface to the bcrypt digest algorithm
         say "Try again!";
     }
 
+    # Now that you've seen how cumbersome/silly that is,
+    # please use Crypt::Bcrypt instead of this module.
+
 =head1 NOTICE
 
 While maintenance for L<Digest::Bcrypt> will continue, there's no reason to use
-L<Digest::Bcrypt> when L<Crypt::Bcrypt> already exists.  We suggest
+L<Digest::Bcrypt> when L<Crypt::Bcrypt> already exists.  We strongly suggest
 that you use L<Crypt::Bcrypt> instead.
 
+This C<Digest::Bcrypt> interface is crufty and laborious to use when compared
+to that of L<Crypt::Bcrypt>.
+
 =head1 DESCRIPTION
 
 L<Digest::Bcrypt> provides a L<Digest>-based interface to the
@@ -239,7 +250,7 @@ L<Digest::Bcrypt> implements the following attributes.
     $bcrypt = $bcrypt->cost(20); # allows for method chaining
     my $cost = $bcrypt->cost();
 
-An integer in the range C<1..31>, this is required.
+An integer in the range C<5..31>, this is required.
 
 See L<Crypt::Eksblowfish::Bcrypt> for a detailed description of C<cost>
 in the context of the bcrypt algorithm.
@@ -262,19 +273,6 @@ provide a truly randomized salt.
 
 When called with no arguments, it will return the current salt.
 
-=head2 type
-
-    # method chaining on mutations as invocant is returned
-    $bcrypt = $bcrypt->type('2b');
-    say $bcrypt->type(); # 2b
-
-This sets the subtype of bcrypt used. These subtypes are as defined in L<Crypt::Bcrypt>.
-The available types are:
-C<2b> which is the current standard,
-C<2a> which is older; it's the one used in L<Crypt::Eksblowfish>,
-C<2y> which is considerd equivalent to C<2b> and used in PHP.
-C<2x> which is very broken and only needed to work with ancient PHP versions.
-
 =head2 settings
 
     $bcrypt = $bcrypt->settings('$2a$20$GA.eY03tb02ea0DqbA.eG.'); # allows for method chaining
@@ -288,6 +286,19 @@ For details on the C<settings> string requirements, please see L<Crypt::Eksblowf
 
 When called with no arguments, it will return the current settings string.
 
+=head2 type
+
+    $bcrypt = $bcrypt->type('2b');
+    # method chaining on mutations
+    say $bcrypt->type(); # 2b
+
+This sets the subtype of bcrypt used. These subtypes are as defined in L<Crypt::Bcrypt>.
+The available types are:
+C<2b> which is the current standard,
+C<2a> which is older; it's the one used in L<Crypt::Eksblowfish>,
+C<2y> which is considered equivalent to C<2b> and used in PHP.
+C<2x> which is very broken and only needed to work with ancient PHP versions.
+
 =head1 METHODS
 
 L<Digest::Bcrypt> inherits all methods from L<Digest::base> and implements/overrides
